@@ -214,7 +214,7 @@ data_preprocess <- function(data) { # , varnames) {
                    } else if (is.list(x)) {
                      x <- data_list2array(x) # list to array
                    } else if (is.logical(x)) {
-                     x <- as.integer(x)
+                     storage.mode(x) <- "integer"
                    }
 
                    ## Now we stop whenever we have NA in the data
@@ -310,7 +310,7 @@ check_args <- function(argss) {
 }
 
 #
-# model_code <- read_model_from_con('http://stan.googlecode.com/git/src/models/bugs_examples/vol1/dyes/dyes.stan')
+# model_code <- read_model_from_con('https://stan.googlecode.com/git/src/models/bugs_examples/vol1/dyes/dyes.stan')
 # cat(model_code)
 
 
@@ -364,7 +364,7 @@ config_argss <- function(chains, iter, warmup, thin,
   if (thin < 1 || thin > iter)
     stop("parameter 'thin' should be a positive integer less than 'iter'")
   warmup <- max(0, as.integer(warmup))
-  if (warmup > iter)
+  if (warmup >= iter)
     stop("parameter 'warmup' should be an integer less than 'iter'")
   chains <- as.integer(chains)
   if (chains < 1)
@@ -934,7 +934,7 @@ rstancolgrey <- rgb(matrix(c(247, 247, 247, 204, 204, 204, 150, 150, 150, 82, 82
                     alpha = 100,
                     names = paste(1:4), maxColorValue = 255)
 
-# from http://colorbrewer2.org/, colorblind safe,
+# from https://colorbrewer2.org/, colorblind safe,
 # 6 different colors, diverging
 rstancolc <- rgb(matrix(c(230, 97, 1,
                           153, 142, 195,
@@ -954,8 +954,8 @@ get_par_summary <- function(sim, n, probs = default_summary_probs()) {
                  if (sim$warmup2[i] == 0) sim$samples[[i]][[n]]
                  else sim$samples[[i]][[n]][-(1:sim$warmup2[i])]
                })
-  msdfun <- function(chain) c(mean(chain), sd(chain))
-  qfun <- function(chain) quantile(chain, probs = probs)
+  msdfun <- function(chain) c(mean(chain, na.rm = TRUE), sd(chain, na.rm = TRUE))
+  qfun <- function(chain) quantile(chain, probs = probs, na.rm = TRUE)
   c_msd <- unlist(lapply(ss, msdfun), use.names = FALSE)
   c_quan <- unlist(lapply(ss, qfun), use.names = FALSE)
   ass <- do.call(c, ss)
@@ -984,7 +984,7 @@ get_par_summary_quantile <- function(sim, n, probs = default_summary_probs()) {
                  if (sim$warmup2[i] == 0) sim$samples[[i]][[n]]
                  else sim$samples[[i]][[n]][-(1:sim$warmup2[i])]
                })
-  sumfun <- function(chain) quantile(chain, probs = probs)
+  sumfun <- function(chain) quantile(chain, probs = probs, na.rm = TRUE)
   cs <- lapply(ss, sumfun)
   as <- sumfun(do.call(c, ss))
   list(quan = as, c_quan = unlist(cs, use.names = FALSE))
@@ -1063,19 +1063,27 @@ summary_sim <- function(sim, pars, probs = default_summary_probs()) {
                            stats = probs_str,
                            chains = paste0("chains:", cids))
 
-  ess <-  array(sapply(tidx, function(n) rstan_ess(sim, n)), dim = c(tidx_len, 1))
-  rhat <- array(sapply(tidx, function(n) rstan_splitrhat(sim, n)), dim = c(tidx_len, 1))
-
-  ss <- list(msd = msd, sem = msd[, 2] / sqrt(ess),
-             c_msd = c_msd, quan = quan, c_quan = c_quan,
-             ess = ess, rhat = rhat)
+  if ("diagnostics" %in% names(sim) & "n_eff" %in% names(sim$diagnostics)) {
+      #vb
+      ess <- array(sim$diagnostics$n_eff, dim = c(tidx_len, 1))
+      khat <- array(sim$diagnostics$theta_pareto_k, dim = c(tidx_len, 1))
+      mcse <- array(sim$diagnostics$mcse, dim = c(tidx_len, 1))
+      ss <- list(msd = msd, sem = mcse,
+                 c_msd = c_msd, quan = quan, c_quan = c_quan,
+                 ess = ess, khat = khat)
+  } else {
+      ess <-  array(sapply(tidx, function(n) rstan_ess(sim, n)), dim = c(tidx_len, 1))
+      rhat <- array(sapply(tidx, function(n) rstan_splitrhat(sim, n)), dim = c(tidx_len, 1))
+      ss <- list(msd = msd, sem = msd[, 2] / sqrt(ess),
+                 c_msd = c_msd, quan = quan, c_quan = c_quan,
+                 ess = ess, rhat = rhat)
+  }
   attr(ss, "row_major_idx") <- tidx_rowm
   attr(ss, "col_major_idx") <- tidx
   ss
 }
 
 summary_sim_quan <- function(sim, pars, probs = default_summary_probs()) {
-  # cat("summary_sim is called.\n")
   probs_len <- length(probs)
   pars <- if (missing(pars)) sim$pars_oi else check_pars_second(sim, pars)
   tidx <- pars_total_indexes(sim$pars_oi, sim$dims_oi, sim$fnames_oi, pars)
@@ -1372,7 +1380,7 @@ legitimate_model_name <- function(name, obfuscate_name = TRUE) {
   # take advantage of tools such as ccache
 }
 
-boost_url <- function() {"http://www.boost.org/users/download/"}
+boost_url <- function() {"https://www.boost.org/users/download/"}
 
 makeconf_path <- function() {
   RMU <- Sys.getenv("R_MAKEVARS_USER")
@@ -1502,6 +1510,7 @@ read_csv_header <- function(f, comment.char = '#') {
   iter.count <- NA
   save.warmup <- FALSE
   sample.count <- NA_integer_
+  thin <- NULL
   while (length(input <- readLines(con, n = 1)) > 0) {
     niter <- niter + 1
     if (!grepl(comment.char, input)) break;
@@ -1515,9 +1524,15 @@ read_csv_header <- function(f, comment.char = '#') {
     } else {
       warmup.count <- 0L
     }
+    if (grepl("#.*thin", input)){
+      thin <- as.integer(gsub("[^0-9]*([0-9]*).*","\\1",input))
+    }
     if (grepl("#.*save_warmup",input)){
       save.warmup <- !grepl("0",input)
     }
+    if (grepl("#.*output_sample",input)){
+      iter.count <- as.numeric(gsub("[^0-9]*([0-9]*).*","\\1",input))
+    }
 
   }
   header <- input
@@ -1526,7 +1541,10 @@ read_csv_header <- function(f, comment.char = '#') {
       iter.count <- warmup.count + sample.count
     else
       iter.count <- sample.count
-  } 
+  }
+  if(!is.null(thin)){
+    iter.count <- iter.count %/% thin
+  }
   attr(header, "iter.count") <- iter.count
   attr(header, "lineno") <- niter
   close(con)
@@ -1569,10 +1587,8 @@ get_time_from_csv <- function(tlines) {
   t <- rep(NA, 2)
   names(t) <- c("warmup", "sample")
   if (length(tlines) < 2) return(t)
-  warmupt <- gsub(".*#\\s*Elapsed.*:\\s*", "", tlines[1])
-  warmupt <- gsub("\\s*seconds.*$", "", warmupt)
-  samplet <- gsub(".*#\\s*", "", tlines[2])
-  samplet <- gsub("\\s*seconds.*$", "", samplet)
+  warmupt <- gsub("[^0-9.]", "", tlines[1])
+  samplet <- gsub("[^0-9.]", "", tlines[2])
   t[1] <- as.double(warmupt)
   t[2] <- as.double(samplet)
   t
@@ -1586,14 +1602,20 @@ parse_data <- function(cppcode) {
   # pull out object names from the data block
   objects <- gsub("^.* ([0-9A-Za-z_]+).*;.*$", "\\1",
                   cppcode[private:public])
-  
-  in_data <- grep("context__.vals_", cppcode, fixed = TRUE, value = TRUE)
-  in_data <- gsub('^.*\\("(.*)\"\\).*;$', "\\1", in_data)  
-  
-  # get them from the calling environment
-  objects <- intersect(objects, in_data)
-  stuff <- sapply(objects, simplify = FALSE, FUN = dynGet, 
-                  inherits = FALSE, ifnotfound = NULL)
+  # Remove model internal name _data__ suffix for stanc3 v2.30+
+  objects <- gsub("_data__$", "", objects)
+  # Remove model internal name underscores in case of Eigen::Maps
+  objects <- gsub("__$", "\\1", objects)
+  # Remove any bad regex matches that found the end of an Eigen::Map.
+  objects <- gsub("^[[:digit:]]+", "\\1", objects)
+  # Remove empty characters and trim whitespaces
+  objects <- objects[nzchar(trimws(objects))]
+
+  # Get them from the calling environment
+  stuff <- list()
+  for (int in seq_along(objects)) {
+   stuff[[objects[int]]] <- dynGet(objects[int], inherits = FALSE, ifnotfound = NULL)
+  }
   for (i in seq_along(stuff)) if (is.null(stuff[[i]])) {
     if (exists(objects[i], envir = globalenv(), mode = "numeric"))
       stuff[[i]] <- get(objects[i], envir = globalenv(), mode = "numeric")
@@ -1628,61 +1650,6 @@ create_progress_html_file <- function(htmlfname, textfname) {
   cat(src2, file = htmlfname)
 }
 
-throw_sampler_warnings <- function(object) {
-  if (!is(object, "stanfit"))
-    stop("'object' must be of class 'stanfit'")
-  sp <- get_sampler_params(object, inc_warmup = FALSE)
-  n_d <- sum(sapply(sp, FUN = function(x) {
-    if ("divergent__" %in% colnames(x)) return(sum(x[,"divergent__"]))
-    else return(0)
-  }))
-  if (n_d > 0) {
-    ad <- object@stan_args[[1]]$control
-    if (is.null(ad)) ad <- 0.8
-    else {
-      ad <- ad$adapt_delta
-      if (is.null(ad)) ad <- 0.8
-    }
-    warning("There were ", n_d, " divergent transitions after warmup.",
-            " Increasing adapt_delta above ", ad, " may help. See\n",
-            "http://mc-stan.org/misc/warnings.html#divergent-transitions-after-warmup", call. = FALSE)
-  }
-  max_td <- object@stan_args[[1]]$control
-  if (is.null(max_td)) max_td <- 10
-  else {
-    max_td <- max_td$max_treedepth
-    if (is.null(max_td)) max_td <- 10
-  }
-  n_m <- sum(sapply(sp, FUN = function(x) {
-    if ("treedepth__" %in% colnames(x)) return(sum(x[,"treedepth__"] >= max_td))
-    else return(0)
-  }))
-  if (n_m > 0)
-    warning("There were ", n_m,
-            " transitions after warmup that exceeded the maximum treedepth.",
-            " Increase max_treedepth above ", max_td, ". See\n",
-            "http://mc-stan.org/misc/warnings.html#maximum-treedepth-exceeded", call. = FALSE)
-  n_e <- 0L
-  if (is_sfinstance_valid(object) && all(sapply(sp, function(x) "energy__" %in% colnames(x)))) {
-    E <- as.matrix(sapply(sp, FUN = function(x) x[,"energy__"]))
-    threshold <- 0.2
-    if (nrow(E) > 1) {
-      EBFMI <- get_num_upars(object) / apply(E, 2, var)
-      n_e <- sum(EBFMI < threshold, na.rm = TRUE)
-    }
-    else n_e <- 0L
-    if (n_e > 0)
-      warning("There were ", n_e, 
-              " chains where the estimated Bayesian Fraction of Missing Information",
-              " was low. See\n", 
-              "http://mc-stan.org/misc/warnings.html#bfmi-low", call. = FALSE)
-  }
-  if (n_d > 0 || n_m > 0 || n_e > 0) 
-    warning("Examine the pairs() plot to diagnose sampling problems\n",
-            call. = FALSE, noBreaks. = TRUE)
-  return(invisible(NULL))
-}
-
 get_CXX <- function(CXX14 = TRUE) {
   if (.Platform$OS.type != "windows")
     return (system2(file.path(R.home(component = "bin"), "R"),
@@ -1708,17 +1675,42 @@ avoid_crash <- function(mod) {
     c("<pointer: (nil)>", "<pointer: 0x0>")
 }
 
-make_makevars <- function(DIR = tempdir()) {
-  CXX11 <- get_CXX(FALSE)
-  if (!file.exists(CXX11)) CXX11 <- basename(CXX11)
-  Makevars <- c(CXX14 = paste0("CXX14 := ", CXX11),
-                CXX14STD = "CXX14STD := -std=c++1y",
-                CXX14FLAGS = "CXX14FLAGS := -O3")
-  fn <- file.path(DIR, ifelse(.Platform$OS.type == "windows", 
-                              "Makevars.win", "Makevars"))
-  if (!file.exists(fn) && file.access(DIR, mode = 2) == 0) {
-    writeLines(Makevars, con = fn)
-    return(invisible(TRUE))
+# @param x numeric vector
+log_sum_exp <- function(x) {
+  max_x <- max(x)
+  max_x + log(sum(exp(x - max_x)))
+}
+
+sample_indices <- function(wts, n_draws) {
+  ## Stratified resampling
+  ##   Kitagawa, G., Monte Carlo Filter and Smoother for Non-Gaussian
+  ##   Nonlinear State Space Models, Journal of Computational and
+  ##   Graphical Statistics, 5(1):1-25, 1996.
+  K <- length(wts)
+  w <- n_draws * wts # expected number of draws from each model
+  idx <- rep(NA, n_draws)
+
+  c <- 0
+  j <- 0
+
+  for (k in 1:K) {
+    c <- c + w[k]
+    if (c >= 1) {
+      a <- floor(c)
+      c <- c - a
+      idx[j + 1:a] <- k
+      j <- j + a
+    }
+    if (j < n_draws && c >= runif(1)) {
+      c <- c - 1
+      j <- j + 1
+      idx[j] <- k
+    }
   }
-  return(invisible(FALSE))
+  return(idx)
+}
+
+test_221 <- function(cppcode) {
+  grepl("Code generated by Stan version 2.2", cppcode, fixed = TRUE) ||
+  grepl("Code generated by Stan version 3", cppcode, fixed = TRUE)  
 }
