@@ -49,11 +49,15 @@ PKG_CPPFLAGS_env_fun <- function() {
          ' -I"', file.path(inc_path_fun("StanHeaders"), "src", '" '),
          ' -I"', file.path(inc_path_fun("StanHeaders"), '" '),
          ' -I"', file.path(inc_path_fun("RcppParallel"), '" '),
+         utils::capture.output(RcppParallel::CxxFlags()),
          ' -I"', inc_path_fun("rstan"), '"',
          ' -DEIGEN_NO_DEBUG ',
          ' -DBOOST_DISABLE_ASSERTS ',
          ' -DBOOST_PENDING_INTEGER_LOG2_HPP ',
          ' -DSTAN_THREADS ',
+         ' -DUSE_STANC3',
+         ' -DSTRICT_R_HEADERS ',
+         ' -DBOOST_PHOENIX_NO_VARIADIC_EXPRESSION ',
          ' -DBOOST_NO_AUTO_PTR ',
          ' -include ', shQuote(Eigen), ' ',
          ifelse (.Platform$OS.type == "windows", ' -std=c++1y',
@@ -109,19 +113,27 @@ rstanplugin <- function() {
   # cat("INFO: rcpp_pkg_libs = ", rcpp_pkg_libs, "\n")
 
   tbb_libs <- "-ltbb"
-  if (!is.null(tbbmalloc_proxyDllInfo))
-      tbb_libs <- paste(tbb_libs, "-ltbbmalloc -ltbbmalloc_proxy")
 
-  list(includes = '// [[Rcpp::plugins(cpp14)]]\n',
-       body = function(x) x,
-       env = list(PKG_LIBS = paste(rcpp_pkg_libs,
-                                   rstan_StanServices,
-                                   paste0("-L", shQuote(StanHeaders_pkg_libs)),
-                                   "-lStanHeaders",
-                                   paste0("-L", shQuote(RcppParallel_pkg_libs)),
-                                   tbb_libs),
-                  PKG_CPPFLAGS = paste(Rcpp_plugin$env$PKG_CPPFLAGS,
-                                       PKG_CPPFLAGS_env_fun(), collapse = " ")))
+  PL <- paste(rcpp_pkg_libs,
+              shQuote(rstan_StanServices),
+              paste0("-L", shQuote(StanHeaders_pkg_libs)),
+              "-lStanHeaders",
+              paste0("-L", shQuote(RcppParallel_pkg_libs)),
+              tbb_libs,
+              utils::capture.output(RcppParallel::RcppParallelLibs()))
+  if (.Platform$OS.type == "windows") {
+    list(includes = '// [[Rcpp::plugins(cpp14)]]\n',
+         body = function(x) x,
+         env = list(PKG_LIBS = PL,
+                    PKG_CPPFLAGS = paste(Rcpp_plugin$env$PKG_CPPFLAGS,
+                                         PKG_CPPFLAGS_env_fun(), collapse = " ")))
+  } else {
+    list(includes = '// [[Rcpp::plugins(cpp14)]]\n',
+         body = function(x) x,
+         env = list(PKG_LIBS = PL,
+                    PKG_CPPFLAGS = paste(Rcpp_plugin$env$PKG_CPPFLAGS,
+                                         PKG_CPPFLAGS_env_fun(), collapse = " ")))
+  }
 }
 
 
